@@ -145,7 +145,7 @@ giraffe_stacking_average(GiImage **img_array, const GiStackingConfig *config)
               ncol       = 0,
               nrow       = 0,
               i          = 0;
-    cxint     e_code     = 0;
+    /*cxint     e_code     = 0;*/
 
     cxlong    npix       = 0L;
 
@@ -154,7 +154,7 @@ giraffe_stacking_average(GiImage **img_array, const GiStackingConfig *config)
 
 
     /* Not used here! */
-    config = NULL;
+    (void) config;
 
     num_images = _image_array_count(img_array);
 
@@ -182,14 +182,14 @@ giraffe_stacking_average(GiImage **img_array, const GiStackingConfig *config)
 
     for (i = 0; i < num_images; i++) {
 
-        e_code = cpl_image_add(giraffe_image_get(result),
+        /*e_code =*/ cpl_image_add(giraffe_image_get(result),
                                giraffe_image_get(img_array[i]));
 
     }
 
     inverse = 1.0 / num_images;
 
-    e_code = cpl_image_multiply_scalar(giraffe_image_get(result), inverse);
+    /*e_code =*/ cpl_image_multiply_scalar(giraffe_image_get(result), inverse);
 
     return result;
 
@@ -232,7 +232,7 @@ giraffe_stacking_median(GiImage **img_array, const GiStackingConfig *config)
 
 
     /* Not used here! */
-    config = NULL;
+    (void) config;
 
     num_images = _image_array_count(img_array);
 
