@@ -653,37 +653,81 @@ giraffe_table_save(GiTable *self, const cxchar *filename)
         cxint code;
 
         cpl_table *table = giraffe_table_get(self);
-        cpl_propertylist *plist = giraffe_table_get_properties(self);
+        cpl_propertylist *plist0 = giraffe_table_get_properties(self);
+        cpl_propertylist *plist1 = NULL;
 
 
-        if (cpl_propertylist_is_empty(plist)) {
-            plist = NULL;
+        if (cpl_propertylist_is_empty(plist0)) {
+            plist0 = NULL;
         }
 
-        plist = cpl_propertylist_duplicate(plist);
+        plist0 = cpl_propertylist_duplicate(plist0);
+
+
+        /*
+         * Remove keywords which may not appear in table headers.
+         */
+
+        cpl_propertylist_erase(plist0, "BSCALE");
+        cpl_propertylist_erase(plist0, "BZERO");
+        cpl_propertylist_erase(plist0, "BUNIT");
+
+        cpl_propertylist_erase(plist0, "DATAMIN");
+        cpl_propertylist_erase(plist0, "DATAMAX");
 
 
         /* FIXME: Workaround for CPL deficiency. World coordinate
          *        keywords are not removed from table headers.
          */
 
-        cpl_propertylist_erase_regexp(plist, "^CRPIX[0-9]$", 0);
-        cpl_propertylist_erase_regexp(plist, "^CRVAL[0-9]$", 0);
-        cpl_propertylist_erase_regexp(plist, "^CDELT[0-9]$", 0);
-        cpl_propertylist_erase_regexp(plist, "^CTYPE[0-9]$", 0);
+        cpl_propertylist_erase_regexp(plist0, "^CRPIX[0-9]$", 0);
+        cpl_propertylist_erase_regexp(plist0, "^CRVAL[0-9]$", 0);
+        cpl_propertylist_erase_regexp(plist0, "^CDELT[0-9]$", 0);
+        cpl_propertylist_erase_regexp(plist0, "^CTYPE[0-9]$", 0);
 
 
-        code = cpl_table_save(table, plist, plist, filename, CPL_IO_CREATE);
+        /*
+         * Split properties into separate property lists for the primary
+         * and the secondary header
+         */
+
+        plist1 = cpl_propertylist_duplicate(plist0);
+
+
+        /*
+         * Remove header specific keywords from the respective
+         * property list.
+         */
+
+        cpl_propertylist_erase(plist0, "EXTNAME");
+
+        cpl_propertylist_erase(plist1, "DATAMD5");
+        cpl_propertylist_erase(plist1, "INHERIT");
+        cpl_propertylist_erase(plist1, "PIPEFILE");
+        cpl_propertylist_erase(plist1, GIALIAS_ANCESTOR);
+
+
+        /*
+         * Save the table to disk
+         */
+
+        code = cpl_table_save(table, plist0, plist1, filename, CPL_IO_CREATE);
 
         if (code != CPL_ERROR_NONE) {
-            cpl_propertylist_delete(plist);
-            plist = NULL;
+            cpl_propertylist_delete(plist0);
+            plist0 = NULL;
+
+            cpl_propertylist_delete(plist1);
+            plist1 = NULL;
 
             return 1;
         }
 
-        cpl_propertylist_delete(plist);
-        plist = NULL;
+        cpl_propertylist_delete(plist0);
+        plist0 = NULL;
+
+        cpl_propertylist_delete(plist1);
+        plist1 = NULL;
 
     }
 
@@ -736,6 +780,21 @@ giraffe_table_attach(GiTable *self, const cxchar *filename, cxint position,
     plist = cpl_propertylist_duplicate(plist);
 
 
+    /*
+     * Remove keywords which may not appear in table headers.
+     */
+
+    cpl_propertylist_erase(plist, "BSCALE");
+    cpl_propertylist_erase(plist, "BZERO");
+    cpl_propertylist_erase(plist, "BUNIT");
+
+    cpl_propertylist_erase(plist, "DATAMIN");
+    cpl_propertylist_erase(plist, "DATAMAX");
+    cpl_propertylist_erase(plist, "DATAMD5");
+    cpl_propertylist_erase(plist, "INHERIT");
+    cpl_propertylist_erase(plist, "PIPEFILE");
+    cpl_propertylist_erase(plist, GIALIAS_ANCESTOR);
+
     /* FIXME: Workaround for CPL deficiency. World coordinate
      *        keywords are not removed from table headers.
      */
