@@ -33,6 +33,7 @@
 #include <cpl_macros.h>
 #include <cpl_image.h>
 #include <cpl_propertylist.h>
+#include <cpl_parameterlist.h>
 #include <cpl_frameset.h>
 
 
@@ -106,6 +107,7 @@ extern "C" {
         cxchar* recipe;
         cxint sequence;
         cxchar* start;
+        cpl_parameterlist *options;
     };
 
     typedef struct GiRecipeInfo GiRecipeInfo;
