@@ -79,7 +79,7 @@ giwavecalibration_create(cpl_plugin* plugin)
 
 
     /*
-     * We have to provide the option we accept to the application. We
+     * We have to provide the options we accept to the application. We
      * need to setup our parameter list and hook it into the recipe
      * interface.
      */
@@ -256,7 +256,7 @@ giwavecalibration(cpl_parameterlist* config, cpl_frameset* set)
 
     GiFrameCreator creator = NULL;
 
-    GiRecipeInfo info = {(cxchar*)fctid, 1, NULL};
+    GiRecipeInfo info = {(cxchar*)fctid, 1, NULL, config};
 
     GiGroupInfo groups[] = {
         {GIFRAME_ARC_SPECTRUM, CPL_FRAME_GROUP_RAW},
@@ -1088,7 +1088,23 @@ giwavecalibration(cpl_parameterlist* config, cpl_frameset* set)
     }
 
     wcal_config = giraffe_wlcalibration_config_create(config);
-    cx_assert(wcal_config != NULL);
+
+    if (wcal_config == NULL) {
+
+        cpl_msg_error(fctid, "Could not create wavelength calibration "
+                      "setup: error parsing configuration parameters! "
+                      "Aborting ...");
+        giraffe_table_delete(fibers);
+        giraffe_localization_destroy(localization);
+        giraffe_extraction_destroy(extraction);
+        giraffe_table_delete(grating);
+        giraffe_table_delete(slitgeo);
+        giraffe_table_delete(wavelengths);
+        giraffe_table_delete(wcal_initial);
+
+        return 1;
+
+    }
 
     wlsolution = giraffe_wcaldata_new();
 
